@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0 OR BSD-2-Clause
 /*
- * Copyright 2019-2025 Amazon.com, Inc. or its affiliates. All rights reserved.
+ * Copyright 2019-2024 Amazon.com, Inc. or its affiliates. All rights reserved.
  */
 
 #include <assert.h>
@@ -470,6 +470,7 @@ static enum ibv_wc_status to_ibv_status(enum efa_io_comp_status status)
 	case EFA_IO_COMP_STATUS_REMOTE_ERROR_BAD_LENGTH:
 		return IBV_WC_REM_INV_REQ_ERR;
 	case EFA_IO_COMP_STATUS_LOCAL_ERROR_UNRESP_REMOTE:
+	case EFA_IO_COMP_STATUS_LOCAL_ERROR_UNREACH_REMOTE:
 		return IBV_WC_RESP_TIMEOUT_ERR;
 	case EFA_IO_COMP_STATUS_REMOTE_ERROR_BAD_ADDRESS:
 		return IBV_WC_REM_ACCESS_ERR;
@@ -963,13 +964,13 @@ static struct ibv_cq_ex *create_cq(struct ibv_context *ibvctx,
 	}
 
 	if (resp.comp_mask & EFA_CREATE_CQ_RESP_DB_OFF) {
-		cq->db_mmap_addr = mmap(NULL,
-					to_efa_dev(ibvctx->device)->pg_sz, PROT_WRITE,
-					MAP_SHARED, ibvctx->cmd_fd, resp.db_mmap_key);
-		if (cq->db_mmap_addr == MAP_FAILED)
+		cq->db = mmap(NULL,
+			      to_efa_dev(ibvctx->device)->pg_sz, PROT_WRITE,
+			      MAP_SHARED, ibvctx->cmd_fd, resp.db_mmap_key);
+		if (cq->db == MAP_FAILED)
 			goto err_unmap_cq;
 
-		cq->db = (uint32_t *)(cq->db_mmap_addr + resp.db_off);
+		cq->db = (uint32_t *)((uint8_t *)cq->db + resp.db_off);
 	}
 
 	efa_cq_fill_pfns(cq, attr, efa_attr);
@@ -1064,7 +1065,7 @@ int efa_destroy_cq(struct ibv_cq *ibvcq)
 		return err;
 	}
 
-	munmap(cq->db_mmap_addr, to_efa_dev(cq->dev)->pg_sz);
+	munmap(cq->db, to_efa_dev(cq->dev)->pg_sz);
 	munmap(cq->buf, cq->buf_size);
 
 	pthread_spin_destroy(&cq->lock);
@@ -1500,6 +1501,8 @@ static struct ibv_qp *create_qp(struct ibv_context *ibvctx,
 	if (efa_attr->flags & EFADV_QP_FLAGS_UNSOLICITED_WRITE_RECV)
 		req.flags |= EFA_CREATE_QP_WITH_UNSOLICITED_WRITE_RECV;
 
+	req.sl = efa_attr->sl;
+
 	err = ibv_cmd_create_qp_ex(ibvctx, &qp->verbs_qp,
 				   attr, &req.ibv_cmd, sizeof(req),
 				   &resp.ibv_resp, sizeof(resp));
@@ -2448,7 +2451,7 @@ int efa_post_recv(struct ibv_qp *ibvqp, struct ibv_recv_wr *wr,
 			addr = wr->sg_list[i].addr;
 
 			/* Set RX buffer desc from SGE */
-			rx_buf.length = min_t(uint32_t, wr->sg_list[i].length, UINT16_MAX);
+			rx_buf.length = wr->sg_list[i].length;
 			EFA_SET(&rx_buf.lkey_ctrl, EFA_IO_RX_DESC_LKEY,
 				wr->sg_list[i].lkey);
 			rx_buf.buf_addr_lo = addr;
